@@ -719,22 +719,31 @@ class Turkish(TurkishClass):
         return self.common_return(**kwargs)
 
     def past_progressive_alternative_narrative(self, **kwargs):
+        negative = kwargs.get('negative')
+        question = kwargs.get('question')
+        person = kwargs.get('person', 3)
+        plural = kwargs.get('plural')
+
+        plural = person == 3 and plural
+
         self.word = self.present_continuous_simple_alternative(
             person=3,
-            negative=kwargs.get('negative'),
-            question=kwargs.get('question')
+            negative=negative,
+            question=question,
+            plural=plural
         ).to_string()
 
+        plural = kwargs.get('plural')
+
+        if person == 3 and plural:
+            plural = False
+
         self.if_ends_with_vowel('y')
 
-        if kwargs.get('person') == 3 and kwargs.get('plural'):
-            self.concat(f'd{self.letter_i()}')
-            self.plural()
-        else:
-            self.word = self.past_definite(
-                person=kwargs.get('person'),
-                plural=kwargs.get('plural')
-            ).to_string()
+        self.word = self.past_definite(
+            person=person,
+            plural=plural
+        ).to_string()
 
         return self.common_return(**kwargs)
 
